@@ -1,105 +1,103 @@
 package Net::DNS::RR::GPOS;
 
-#
-# $Id: GPOS.pm 1348 2015-05-27 09:55:13Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: GPOS.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::GPOS - DNS GPOS resource record
 
 =cut
 
-
 use integer;
 
 use Carp;
 use Net::DNS::Text;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+sub _decode_rdata {			## decode rdata from wire-format octet string
+	my ( $self, $data, $offset ) = @_;
 
 	my $limit = $offset + $self->{rdlength};
-	( $self->{latitude},  $offset ) = decode Net::DNS::Text( $data, $offset ) if $offset < $limit;
-	( $self->{longitude}, $offset ) = decode Net::DNS::Text( $data, $offset ) if $offset < $limit;
-	( $self->{altitude},  $offset ) = decode Net::DNS::Text( $data, $offset ) if $offset < $limit;
+	( $self->{latitude},  $offset ) = Net::DNS::Text->decode( $data, $offset ) if $offset < $limit;
+	( $self->{longitude}, $offset ) = Net::DNS::Text->decode( $data, $offset ) if $offset < $limit;
+	( $self->{altitude},  $offset ) = Net::DNS::Text->decode( $data, $offset ) if $offset < $limit;
 	croak('corrupt GPOS data') unless $offset == $limit;	# more or less FUBAR
+	return;
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless defined $self->{altitude};
-	join '', map $self->{$_}->encode, qw(latitude longitude altitude);
+	return join '', map { $self->{$_}->encode } qw(latitude longitude altitude);
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless defined $self->{altitude};
-	join ' ', map $self->{$_}->string, qw(latitude longitude altitude);
+	return join ' ', map { $self->{$_}->string } qw(latitude longitude altitude);
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+sub _parse_rdata {			## populate RR from rdata in argument list
+	my ( $self, @argument ) = @_;
 
-	$self->latitude(shift);
-	$self->longitude(shift);
-	$self->altitude(shift);
-	die 'too many arguments for GPOS' if scalar @_;
+	foreach (qw(latitude longitude altitude)) { $self->$_( shift @argument ) }
+	die 'too many arguments for GPOS' if scalar @argument;
+	return;
 }
 
 
-sub defaults() {			## specify RR attribute default values
+sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
-	$self->parse_rdata(qw(0.0 0.0 0.0));
+	$self->_parse_rdata(qw(0.0 0.0 0.0));
+	return;
 }
 
 
 sub latitude {
-	my $self = shift;
-	$self->{latitude} = _fp2text(shift) if scalar @_;
-	_text2fp( $self->{latitude} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{latitude} = _fp2text($_) }
+	return defined(wantarray) ? _text2fp( $self->{latitude} ) : undef;
 }
 
 
 sub longitude {
-	my $self = shift;
-	$self->{longitude} = _fp2text(shift) if scalar @_;
-	_text2fp( $self->{longitude} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{longitude} = _fp2text($_) }
+	return defined(wantarray) ? _text2fp( $self->{longitude} ) : undef;
 }
 
 
 sub altitude {
-	my $self = shift;
-	$self->{altitude} = _fp2text(shift) if scalar @_;
-	_text2fp( $self->{altitude} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{altitude} = _fp2text($_) }
+	return defined(wantarray) ? _text2fp( $self->{altitude} ) : undef;
 }
 
 
 ########################################
 
 sub _fp2text {
-	return new Net::DNS::Text( sprintf( '%1.10g', shift ) );
+	return Net::DNS::Text->new( sprintf( '%1.10g', shift ) );
 }
 
 sub _text2fp {
 	no integer;
-	return 0.0 + shift->value;
+	return ( 0.0 + shift->value );
 }
 
+########################################
+
 
 1;
 __END__
@@ -108,7 +106,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name GPOS latitude longitude altitude');
+    $rr = Net::DNS::RR->new('name GPOS latitude longitude altitude');
 
 =head1 DESCRIPTION
 
@@ -159,7 +157,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -176,6 +174,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1712
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1712|https://tools.ietf.org/html/rfc1712>
 
 =cut
