@@ -1,39 +1,36 @@
 package Net::DNS::RR::MG;
 
-#
-# $Id: MG.pm 1528 2017-01-18 21:44:58Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: MG.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::MG - DNS MG resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->{mgmname} = decode Net::DNS::DomainName1035(@_);
+	$self->{mgmname} = Net::DNS::DomainName1035->decode(@argument);
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
 	my $mgmname = $self->{mgmname} || return '';
-	$mgmname->encode(@_);
+	return $mgmname->encode(@argument);
 }
 
 
@@ -41,22 +38,22 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my $mgmname = $self->{mgmname} || return '';
-	$mgmname->string;
+	return $mgmname->string;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->mgmname(shift);
+	$self->mgmname(@argument);
+	return;
 }
 
 
 sub mgmname {
-	my $self = shift;
-
-	$self->{mgmname} = new Net::DNS::DomainName1035(shift) if scalar @_;
-	$self->{mgmname}->name if $self->{mgmname};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{mgmname} = Net::DNS::DomainName1035->new($_) }
+	return $self->{mgmname} ? $self->{mgmname}->name : undef;
 }
 
 
@@ -67,7 +64,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name MG mgmname');
+    $rr = Net::DNS::RR->new('name MG mgmname');
 
 =head1 DESCRIPTION
 
@@ -105,7 +102,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -122,6 +119,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1035 Section 3.3.6
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1035(3.3.6)|https://tools.ietf.org/html/rfc1035>
 
 =cut
